# Generated by ariadne-codegen
# Source: openhexa/cli/graphql/queries.graphql

from typing import Any, Dict, Optional, Union

from .base_client import BaseClient
from .base_model import UNSET, UnsetType
from .get_workspace_pipelines import GetWorkspacePipelines


def gql(q: str) -> str:
    return q


class Client(BaseClient):
    def get_workspace_pipelines(
        self,
        workspace_slug: str,
        name: Union[Optional[str], UnsetType] = UNSET,
        page: Union[Optional[int], UnsetType] = UNSET,
        per_page: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> GetWorkspacePipelines:
        query = gql(
            """
            query getWorkspacePipelines($workspaceSlug: String!, $name: String, $page: Int = 1, $perPage: Int = 10) {
              pipelines(
                workspaceSlug: $workspaceSlug
                name: $name
                page: $page
                perPage: $perPage
              ) {
                totalPages
                items {
                  id
                  code
                  name
                  type
                  currentVersion {
                    id
                    name
                    versionNumber
                  }
                }
              }
            }
            """
        )
        variables: Dict[str, object] = {
            "workspaceSlug": workspace_slug,
            "name": name,
            "page": page,
            "perPage": per_page,
        }
        response = self.execute(
            query=query,
            operation_name="getWorkspacePipelines",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return GetWorkspacePipelines.model_validate(data)



# Generated by ariadne-codegen

from .base_client import BaseClient
from .base_model import BaseModel, Upload
from .client import Client
from .enums import (
    AccessmodAccessibilityAnalysisAlgorithm,
    AccessmodAccessRequestStatus,
    AccessmodAnalysisStatus,
    AccessmodAnalysisType,
    AccessmodFilesetFormat,
    AccessmodFilesetMode,
    AccessmodFilesetRoleCode,
    AccessmodFilesetStatus,
    AccessmodProjectOrder,
    AddToFavoritesError,
    ApproveAccessmodAccessRequestError,
    ArchiveWorkspaceError,
    BucketObjectType,
    ConnectionType,
    CreateAccessmodAccessibilityAnalysisError,
    CreateAccessmodFileError,
    CreateAccessmodFilesetError,
    CreateAccessmodProjectError,
    CreateAccessmodProjectMemberError,
    CreateAccessmodZonalStatisticsError,
    CreateBucketFolderError,
    CreateConnectionError,
    CreateDatasetError,
    CreateDatasetVersionError,
    CreateDatasetVersionFileError,
    CreateMembershipError,
    CreatePipelineFromTemplateVersionError,
    CreatePipelineTemplateVersionError,
    CreateTeamError,
    CreateTemplateVersionPermissionReason,
    CreateWebappError,
    CreateWorkspaceError,
    DAGRunOrderBy,
    DAGRunStatus,
    DAGRunTrigger,
    DeclineWorkspaceInvitationError,
    DeleteAccessmodAnalysisError,
    DeleteAccessmodFilesetError,
    DeleteAccessmodProjectError,
    DeleteAccessmodProjectMemberError,
    DeleteBucketObjectError,
    DeleteConnectionError,
    DeleteDatasetError,
    DeleteDatasetLinkError,
    DeleteDatasetVersionError,
    DeleteMembershipError,
    DeleteMetadataAttributeError,
    DeletePipelineVersionError,
    DeleteTeamError,
    DeleteTemplateVersionError,
    DeleteWebappError,
    DeleteWorkspaceDatabaseTableError,
    DeleteWorkspaceError,
    DeleteWorkspaceInvitationError,
    DeleteWorkspaceMemberError,
    DenyAccessmodAccessRequestError,
    DHIS2ConnectionError,
    DHIS2ConnectionStatus,
    DHIS2MetadataType,
    DisableTwoFactorError,
    EnableTwoFactorError,
    FileSampleStatus,
    FileType,
    GenerateChallengeError,
    GenerateNewDatabasePasswordError,
    GeneratePipelineWebhookUrlError,
    GenerateWorkspaceTokenError,
    InviteWorkspaceMembershipError,
    JoinWorkspaceError,
    LaunchAccessmodAnalysisError,
    LaunchNotebookServerError,
    LinkDatasetError,
    LoginError,
    MembershipRole,
    MessagePriority,
    OrderByDirection,
    ParameterType,
    ParameterWidget,
    PermissionMode,
    PinDatasetError,
    PipelineError,
    PipelineNotificationLevel,
    PipelineRecipientError,
    PipelineRunOrderBy,
    PipelineRunStatus,
    PipelineRunTrigger,
    PipelineTemplateError,
    PipelineType,
    PrepareObjectDownloadError,
    PrepareObjectUploadError,
    PrepareVersionFileDownloadError,
    RegisterError,
    RemoveFromFavoritesError,
    RequestAccessmodAccessError,
    ResendWorkspaceInvitationError,
    RunDAGError,
    SetDAGRunFavoriteError,
    SetMetadataAttributeError,
    SetPasswordError,
    UpdateAccessmodAccessibilityAnalysisError,
    UpdateAccessmodFilesetError,
    UpdateAccessmodProjectError,
    UpdateAccessmodProjectMemberError,
    UpdateAccessmodZonalStatisticsError,
    UpdateConnectionError,
    UpdateDAGError,
    UpdateDatasetError,
    UpdateDatasetVersionError,
    UpdateMembershipError,
    UpdatePipelineError,
    UpdatePipelineVersionError,
    UpdateTeamError,
    UpdateTemplateError,
    UpdateTemplateVersionError,
    UpdateUserError,
    UpdateWebappError,
    UpdateWorkspaceError,
    UpdateWorkspaceMemberError,
    UpgradePipelineVersionFromTemplateError,
    VerifyDeviceError,
    WorkspaceInvitationStatus,
    WorkspaceMembershipRole,
)
from .exceptions import (
    GraphQLClientError,
    GraphQLClientGraphQLError,
    GraphQLClientGraphQLMultiError,
    GraphQLClientHttpError,
    GraphQLClientInvalidResponseError,
)
from .get_workspace_pipelines import (
    GetWorkspacePipelines,
    GetWorkspacePipelinesPipelines,
    GetWorkspacePipelinesPipelinesItems,
    GetWorkspacePipelinesPipelinesItemsCurrentVersion,
)
from .input_types import (
    AddPipelineOutputInput,
    AddToFavoritesInput,
    ApproveAccessmodAccessRequestInput,
    ArchiveWorkspaceInput,
    ConnectionFieldInput,
    CountryInput,
    CreateAccessmodAccessibilityAnalysisInput,
    CreateAccessmodFileInput,
    CreateAccessmodFilesetInput,
    CreateAccessmodProjectInput,
    CreateAccessmodProjectMemberInput,
    CreateAccessmodZonalStatisticsInput,
    CreateBucketFolderInput,
    CreateConnectionInput,
    CreateDatasetInput,
    CreateDatasetVersionFileInput,
    CreateDatasetVersionInput,
    CreateMembershipInput,
    CreatePipelineFromTemplateVersionInput,
    CreatePipelineInput,
    CreatePipelineRecipientInput,
    CreatePipelineTemplateVersionInput,
    CreateTeamInput,
    CreateWebappInput,
    CreateWorkspaceInput,
    DeclineWorkspaceInvitationInput,
    DeleteAccessmodAnalysisInput,
    DeleteAccessmodFilesetInput,
    DeleteAccessmodProjectInput,
    DeleteAccessmodProjectMemberInput,
    DeleteBucketObjectInput,
    DeleteConnectionInput,
    DeleteDatasetInput,
    DeleteDatasetLinkInput,
    DeleteDatasetVersionInput,
    DeleteMembershipInput,
    DeleteMetadataAttributeInput,
    DeletePipelineInput,
    DeletePipelineRecipientInput,
    DeletePipelineTemplateInput,
    DeletePipelineVersionInput,
    DeleteTeamInput,
    DeleteTemplateVersionInput,
    DeleteWebappInput,
    DeleteWorkspaceDatabaseTableInput,
    DeleteWorkspaceInput,
    DeleteWorkspaceInvitationInput,
    DeleteWorkspaceMemberInput,
    DenyAccessmodAccessRequestInput,
    DisableTwoFactorInput,
    EnableTwoFactorInput,
    GenerateDatasetUploadUrlInput,
    GenerateNewDatabasePasswordInput,
    GeneratePipelineWebhookUrlInput,
    GenerateWorkspaceTokenInput,
    InviteWorkspaceMemberInput,
    JoinWorkspaceInput,
    LaunchAccessmodAnalysisInput,
    LaunchNotebookServerInput,
    LinkDatasetInput,
    LoginInput,
    LogPipelineMessageInput,
    OrganizationInput,
    ParameterInput,
    PinDatasetInput,
    PipelineTokenInput,
    PrepareAccessmodFileDownloadInput,
    PrepareAccessmodFilesetVisualizationDownloadInput,
    PrepareAccessmodFileUploadInput,
    PrepareDownloadURLInput,
    PrepareObjectDownloadInput,
    PrepareObjectUploadInput,
    PrepareVersionFileDownloadInput,
    RegisterInput,
    RemoveFromFavoritesInput,
    RequestAccessmodAccessInput,
    ResendWorkspaceInvitationInput,
    ResetPasswordInput,
    RunDAGInput,
    RunPipelineInput,
    SetDAGRunFavoriteInput,
    SetMetadataAttributeInput,
    SetPasswordInput,
    StopPipelineInput,
    UpdateAccessmodAccessibilityAnalysisInput,
    UpdateAccessmodFilesetInput,
    UpdateAccessmodProjectInput,
    UpdateAccessmodProjectMemberInput,
    UpdateAccessmodZonalStatisticsInput,
    UpdateConnectionInput,
    UpdateDAGInput,
    UpdateDatasetInput,
    UpdateDatasetVersionInput,
    UpdateMembershipInput,
    UpdatePipelineInput,
    UpdatePipelineProgressInput,
    UpdatePipelineRecipientInput,
    UpdatePipelineVersionInput,
    UpdateTeamInput,
    UpdateTemplateInput,
    UpdateTemplateVersionInput,
    UpdateUserInput,
    UpdateWebappInput,
    UpdateWorkspaceInput,
    UpdateWorkspaceMemberInput,
    UpgradePipelineVersionFromTemplateInput,
    UploadPipelineInput,
    VerifyDeviceInput,
)

__all__ = [
    "AccessmodAccessRequestStatus",
    "AccessmodAccessibilityAnalysisAlgorithm",
    "AccessmodAnalysisStatus",
    "AccessmodAnalysisType",
    "AccessmodFilesetFormat",
    "AccessmodFilesetMode",
    "AccessmodFilesetRoleCode",
    "AccessmodFilesetStatus",
    "AccessmodProjectOrder",
    "AddPipelineOutputInput",
    "AddToFavoritesError",
    "AddToFavoritesInput",
    "ApproveAccessmodAccessRequestError",
    "ApproveAccessmodAccessRequestInput",
    "ArchiveWorkspaceError",
    "ArchiveWorkspaceInput",
    "BaseClient",
    "BaseModel",
    "BucketObjectType",
    "Client",
    "ConnectionFieldInput",
    "ConnectionType",
    "CountryInput",
    "CreateAccessmodAccessibilityAnalysisError",
    "CreateAccessmodAccessibilityAnalysisInput",
    "CreateAccessmodFileError",
    "CreateAccessmodFileInput",
    "CreateAccessmodFilesetError",
    "CreateAccessmodFilesetInput",
    "CreateAccessmodProjectError",
    "CreateAccessmodProjectInput",
    "CreateAccessmodProjectMemberError",
    "CreateAccessmodProjectMemberInput",
    "CreateAccessmodZonalStatisticsError",
    "CreateAccessmodZonalStatisticsInput",
    "CreateBucketFolderError",
    "CreateBucketFolderInput",
    "CreateConnectionError",
    "CreateConnectionInput",
    "CreateDatasetError",
    "CreateDatasetInput",
    "CreateDatasetVersionError",
    "CreateDatasetVersionFileError",
    "CreateDatasetVersionFileInput",
    "CreateDatasetVersionInput",
    "CreateMembershipError",
    "CreateMembershipInput",
    "CreatePipelineFromTemplateVersionError",
    "CreatePipelineFromTemplateVersionInput",
    "CreatePipelineInput",
    "CreatePipelineRecipientInput",
    "CreatePipelineTemplateVersionError",
    "CreatePipelineTemplateVersionInput",
    "CreateTeamError",
    "CreateTeamInput",
    "CreateTemplateVersionPermissionReason",
    "CreateWebappError",
    "CreateWebappInput",
    "CreateWorkspaceError",
    "CreateWorkspaceInput",
    "DAGRunOrderBy",
    "DAGRunStatus",
    "DAGRunTrigger",
    "DHIS2ConnectionError",
    "DHIS2ConnectionStatus",
    "DHIS2MetadataType",
    "DeclineWorkspaceInvitationError",
    "DeclineWorkspaceInvitationInput",
    "DeleteAccessmodAnalysisError",
    "DeleteAccessmodAnalysisInput",
    "DeleteAccessmodFilesetError",
    "DeleteAccessmodFilesetInput",
    "DeleteAccessmodProjectError",
    "DeleteAccessmodProjectInput",
    "DeleteAccessmodProjectMemberError",
    "DeleteAccessmodProjectMemberInput",
    "DeleteBucketObjectError",
    "DeleteBucketObjectInput",
    "DeleteConnectionError",
    "DeleteConnectionInput",
    "DeleteDatasetError",
    "DeleteDatasetInput",
    "DeleteDatasetLinkError",
    "DeleteDatasetLinkInput",
    "DeleteDatasetVersionError",
    "DeleteDatasetVersionInput",
    "DeleteMembershipError",
    "DeleteMembershipInput",
    "DeleteMetadataAttributeError",
    "DeleteMetadataAttributeInput",
    "DeletePipelineInput",
    "DeletePipelineRecipientInput",
    "DeletePipelineTemplateInput",
    "DeletePipelineVersionError",
    "DeletePipelineVersionInput",
    "DeleteTeamError",
    "DeleteTeamInput",
    "DeleteTemplateVersionError",
    "DeleteTemplateVersionInput",
    "DeleteWebappError",
    "DeleteWebappInput",
    "DeleteWorkspaceDatabaseTableError",
    "DeleteWorkspaceDatabaseTableInput",
    "DeleteWorkspaceError",
    "DeleteWorkspaceInput",
    "DeleteWorkspaceInvitationError",
    "DeleteWorkspaceInvitationInput",
    "DeleteWorkspaceMemberError",
    "DeleteWorkspaceMemberInput",
    "DenyAccessmodAccessRequestError",
    "DenyAccessmodAccessRequestInput",
    "DisableTwoFactorError",
    "DisableTwoFactorInput",
    "EnableTwoFactorError",
    "EnableTwoFactorInput",
    "FileSampleStatus",
    "FileType",
    "GenerateChallengeError",
    "GenerateDatasetUploadUrlInput",
    "GenerateNewDatabasePasswordError",
    "GenerateNewDatabasePasswordInput",
    "GeneratePipelineWebhookUrlError",
    "GeneratePipelineWebhookUrlInput",
    "GenerateWorkspaceTokenError",
    "GenerateWorkspaceTokenInput",
    "GetWorkspacePipelines",
    "GetWorkspacePipelinesPipelines",
    "GetWorkspacePipelinesPipelinesItems",
    "GetWorkspacePipelinesPipelinesItemsCurrentVersion",
    "GraphQLClientError",
    "GraphQLClientGraphQLError",
    "GraphQLClientGraphQLMultiError",
    "GraphQLClientHttpError",
    "GraphQLClientInvalidResponseError",
    "InviteWorkspaceMemberInput",
    "InviteWorkspaceMembershipError",
    "JoinWorkspaceError",
    "JoinWorkspaceInput",
    "LaunchAccessmodAnalysisError",
    "LaunchAccessmodAnalysisInput",
    "LaunchNotebookServerError",
    "LaunchNotebookServerInput",
    "LinkDatasetError",
    "LinkDatasetInput",
    "LogPipelineMessageInput",
    "LoginError",
    "LoginInput",
    "MembershipRole",
    "MessagePriority",
    "OrderByDirection",
    "OrganizationInput",
    "ParameterInput",
    "ParameterType",
    "ParameterWidget",
    "PermissionMode",
    "PinDatasetError",
    "PinDatasetInput",
    "PipelineError",
    "PipelineNotificationLevel",
    "PipelineRecipientError",
    "PipelineRunOrderBy",
    "PipelineRunStatus",
    "PipelineRunTrigger",
    "PipelineTemplateError",
    "PipelineTokenInput",
    "PipelineType",
    "PrepareAccessmodFileDownloadInput",
    "PrepareAccessmodFileUploadInput",
    "PrepareAccessmodFilesetVisualizationDownloadInput",
    "PrepareDownloadURLInput",
    "PrepareObjectDownloadError",
    "PrepareObjectDownloadInput",
    "PrepareObjectUploadError",
    "PrepareObjectUploadInput",
    "PrepareVersionFileDownloadError",
    "PrepareVersionFileDownloadInput",
    "RegisterError",
    "RegisterInput",
    "RemoveFromFavoritesError",
    "RemoveFromFavoritesInput",
    "RequestAccessmodAccessError",
    "RequestAccessmodAccessInput",
    "ResendWorkspaceInvitationError",
    "ResendWorkspaceInvitationInput",
    "ResetPasswordInput",
    "RunDAGError",
    "RunDAGInput",
    "RunPipelineInput",
    "SetDAGRunFavoriteError",
    "SetDAGRunFavoriteInput",
    "SetMetadataAttributeError",
    "SetMetadataAttributeInput",
    "SetPasswordError",
    "SetPasswordInput",
    "StopPipelineInput",
    "UpdateAccessmodAccessibilityAnalysisError",
    "UpdateAccessmodAccessibilityAnalysisInput",
    "UpdateAccessmodFilesetError",
    "UpdateAccessmodFilesetInput",
    "UpdateAccessmodProjectError",
    "UpdateAccessmodProjectInput",
    "UpdateAccessmodProjectMemberError",
    "UpdateAccessmodProjectMemberInput",
    "UpdateAccessmodZonalStatisticsError",
    "UpdateAccessmodZonalStatisticsInput",
    "UpdateConnectionError",
    "UpdateConnectionInput",
    "UpdateDAGError",
    "UpdateDAGInput",
    "UpdateDatasetError",
    "UpdateDatasetInput",
    "UpdateDatasetVersionError",
    "UpdateDatasetVersionInput",
    "UpdateMembershipError",
    "UpdateMembershipInput",
    "UpdatePipelineError",
    "UpdatePipelineInput",
    "UpdatePipelineProgressInput",
    "UpdatePipelineRecipientInput",
    "UpdatePipelineVersionError",
    "UpdatePipelineVersionInput",
    "UpdateTeamError",
    "UpdateTeamInput",
    "UpdateTemplateError",
    "UpdateTemplateInput",
    "UpdateTemplateVersionError",
    "UpdateTemplateVersionInput",
    "UpdateUserError",
    "UpdateUserInput",
    "UpdateWebappError",
    "UpdateWebappInput",
    "UpdateWorkspaceError",
    "UpdateWorkspaceInput",
    "UpdateWorkspaceMemberError",
    "UpdateWorkspaceMemberInput",
    "UpgradePipelineVersionFromTemplateError",
    "UpgradePipelineVersionFromTemplateInput",
    "Upload",
    "UploadPipelineInput",
    "VerifyDeviceError",
    "VerifyDeviceInput",
    "WorkspaceInvitationStatus",
    "WorkspaceMembershipRole",
]
